@@ -28,7 +28,7 @@
 void showcopyright(const struct cmdinfo *c, const char *v) {
   int fd;
   fd= open(COPYINGFILE,O_RDONLY);
-  if (fd < 0) ohshite(_("cannot open GPL file " COPYINGFILE));
+  if (fd < 0) ohshite(_("cannot open GPL file "));
   do_fd_copy(fd, 1, _("showcopyright"));
   exit(0);
 }
