@@ -186,7 +186,7 @@ static const struct badstatinfo badstatinfos[]= {
     bsyn_status, stat_halfconfigured,
     N_("The following packages are only half configured, probably due to problems\n"
     "configuring them the first time.  The configuration should be retried using\n"
-    "dpkg --configure <package> or the configure menu option in " DSELECT ":\n")
+    "dpkg --configure <package> or the configure menu option in dselect:\n")
   }, {
     bsyn_status, stat_halfinstalled,
     N_("The following packages are only half installed, due to problems during\n"
